from setuptools import setup

setup(name='udacity_probability_prac',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['udacity_probability_prac'],
      author = 'Chan Liang',
      author_email = 'mitbbskg@gmail.com',
      zip_safe=False)
